#
# spec file for package irker
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           irker
Version:        2.18
Release:        2.1
Summary:        Submission tools for IRC notifications
License:        BSD-3-Clause
Group:          Productivity/Networking/IRC
Url:            http://www.catb.org/~esr/irker/
Source0:        http://www.catb.org/~esr/irker/%{name}-%{version}.tar.gz
# https://github.com/shikadilord/irker-svnpoller
Source1:        irker-svnpoller
Source2:        irker.service
Source3:        sysconfig.irker
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkg-config
BuildRequires:  python-setuptools
BuildRequires:  xmlto
BuildRequires:  systemd
%{?systemd_requires}
BuildArch:      noarch

%description
irker is an IRC submission bot that runs as a daemon, accepting JSON requests on a
listener socket that are then passed to IRC servers.
Each JSON object consists of an IRC channel URL and a message string;
irkerd manages IRC server connections so as to deliver messages with minimal join/leave spam.

The use case for which irker was designed is passing notifications from VCS
repository hooks to project IRC channels.
The distribution also includes an installable hook script supporting git and Subversion.


%prep
%setup -q
# Fix MAkefile permissions
sed -i -e 's/-o 0 -g 0//g' Makefile
# Remove irkerd.service file handling (or push "MY" .service upstream)
sed -i -e '/irkerd.service/d' Makefile

%build

%install
mkdir -p %{buildroot}/%{_bindir}
make install DESTDIR=%{buildroot}
cp %{SOURCE1} %{buildroot}/%{_bindir}/irker-svnpoller
cp  irkerhook.py %{buildroot}/%{_bindir}/irkerhook
cp  irk %{buildroot}/%{_bindir}/irk

%if 0%{?suse_version} >= 1210
install -D -m0644 %{SOURCE2} %{buildroot}/%{_unitdir}/irker.service
%endif
install -D -m644 %{SOURCE3} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.irker

cat << EOF >> %{buildroot}/%{_bindir}/irkerhook-git
#!/bin/sh
refname=\$1
old=\$2
new=\$3

%{_bindir}/irkerhook --refname=\${refname} \$(git rev-list --reverse \${old}..\${new})

EOF

sed -i "s|#!/usr/bin/env python|#!%{_bindir}/python2|" %{buildroot}/%{_bindir}/*

%pre
%{_bindir}/getent group irker >/dev/null || %{_sbindir}/groupadd -r irker || :
%{_bindir}/getent passwd irker >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/irker -s /bin/false -c "irker IRC daemon" -g irker irker || :
%if 0%{?suse_version} >= 1210
%service_add_pre %{name}.service
%endif

%post
%if 0%{?suse_version} >= 1210
%service_add_post %{name}.service
%fillup_only
%endif

%preun
%if 0%{?suse_version} >= 1210
%service_del_preun %{name}.service
%endif

%postun
%if 0%{?suse_version} >= 1210
%service_del_postun %{name}.service
%endif

%files
%defattr(0755,root,root)
%{_bindir}/irk
%{_bindir}/irkerd
%{_bindir}/irkerhook
%{_bindir}/irkerhook-git
%{_bindir}/irker-svnpoller
%defattr(0644,root,root)
%doc README COPYING hacking.txt install.txt security.txt
%{_mandir}/man1/irkerhook.1*
%{_mandir}/man1/irk.1*
%{_mandir}/man8/irkerd.8*
%if 0%{?suse_version} >= 1210
%{_unitdir}/irker.service
%endif
%{_localstatedir}/adm/fillup-templates/sysconfig.irker

%changelog
* Thu Aug  3 2017 toddrme2178@gmail.com
- Fix shebangs
* Sat Apr 22 2017 boris@steki.net
- updated to latest upstream version 2.18
  - Add the ability to set the notification-message template
  - Add a reconnect delay (Debian bug #749650).
  - Add proxy support (requres setting some variables in the source file).
  - Use git abbreviated hash to address Debian complaints.
  - Code now runs under either Python 2 or Python 3
  - Emergency backout of getaddrinfo, it randomly hangs.
  - Lookup with getaddrinfo allows use with IPv6.
  - Documentation improvements.
* Wed Jul  2 2014 boris@steki.net
- updated to latest upstream version 2.11
- With -i, message string argument now optional, stdin is read if it is absent.
- Auto-adapt to BSD & OS X log device as well as Linux's.
- irk no longer fails on ircs channel URLs.
* Mon Jun 16 2014 boris@steki.net
- updated to latest upstream version 2.9
  - If irkerd is running in background, log to /dev/syslog (facility daemon).
  - New -H option to set host listening address.
  - Add support for using CertFP to auth to the IRC server, and document it.
  - Various minor improvements to irk.
  - Cope better with branch names containing slashes.
  - Add support for ircs:// and SSL/TLS connections to IRC servers.
  - Add support for per-URL usernames and passwords.
  - Fix for an infinite loop on failing to connect to IRC
  - Bug fix - remove a deadlock we inherited from irclib.
  - Bug fix release - some users reported failure to connect with 2.3.
  - Also prevent a crash if Unicode shows up in the wrong place.
  - -i option enables immediate sending of one line in foreground.
  - Fixed Unicode processing - got busted in 2.0 when irclib was removed.
  - Show Python traceback on higher debug levels.
  - A performance improvement in the git repository hook.
  - Documentation polishing.
  - The dependency on irclib is gone.
  - An email delivery method, suitable for use on SourceForge.
  - irkerhook can now be used as a hg changegroup hook.
  - Prevent misbehavior on UTF-8 in commit metadata.
  - Fix a crash bug on invalid hostnames.
* Fri Mar  1 2013 boris@steki.net
- updated package to latest upstream version 1.17
  - changes from 1.14 to 1.17:
  * Various minor fixes and bulletproofing.Various minor fixes and
    bulletproofing.
  * Deal gracefully with non-ASCII author names and '|' in
    the command line
  * Don't append an extra newline in the Subversion hook.
* Wed Dec  5 2012 boris@steki.net
- initial packaging of irker version 1.14 from git repository
